@@ -13,6 +13,7 @@ test_that("node argument works", {
     point_size_name = "p",
     point_size_mat = -log10(p)
   )
+  expect_is(heatmaply(mtcars, node_type = "scatter", point_size_mat = mtcars), "plotly")
 })
 
 test_that("non-numerics moved to row_side_colors", {
@@ -50,7 +51,7 @@ test_that("SideColors", {
   rs <- rscolors[as.character(rs)]
   h <- heatmaply(mtcars, RowSideColors = rs)
   expect_is(h, "plotly")
-  expect_warning(h <- heatmaply(t(mtcars), ColSideColors = rs))
+  h <- heatmaply(t(mtcars), ColSideColors = rs)
   expect_is(h, "plotly")
 })
 
@@ -73,7 +74,10 @@ test_that("showticklabels", {
   expect_is(h, "plotly")
   h <- heatmaply(mtcars, showticklabels = c(FALSE, FALSE))
   expect_is(h, "plotly")
-  expect_warning(expect_error(heatmaply(mtcars, showticklabels = "a")))
+  expect_error(
+    heatmaply(mtcars, showticklabels = "a"),
+    "showticklabels must be a logical vector of length 2 or 1"
+  )
 })
 
 ## This relies on PhantomJS... it's failing a lot so comment it
@@ -99,7 +103,8 @@ test_that("long_data works", {
   mdf <- reshape2::melt(as.matrix(mtcars))
   colnames(mdf) <- c("name", "variable", "value")
   expect_is(heatmaply(long_data = mdf), "plotly")
-  expect_error(heatmaply(x, mtcars, long_data = mdf))
+  expect_error(heatmaply(mtcars, long_data = mdf),
+    "x and long_data should not be used together")
 })
 
 test_that("heatmaply_na works", {
@@ -142,3 +147,7 @@ test_that("custom_hovertext works", {
     expect_error(heatmaply(mtcars, plot_method = plot_method, custom_hovertext = mat), NA)
   }
 })
+
+test_that("hclust_method=NA works", {
+  expect_error(heatmaply(mtcars, hclust_method=NA), NA)
+})
